@@ -1,9 +1,7 @@
 """Blaster metadata."""
 
 __all__ = [
-    "__name__",
     "__version__"
 ]
 
-__name__ = "blaster"
-__version__ = "0.4.0"
+__version__ = "0.5.0"
